/**
 * apeman react package for icon components.
 * @class ApIcon
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _apemanReactMixinPure = require('apeman-react-mixin-pure');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var assertCache = {};
var notfoundCache = [];

var ASSERT_DELAY = 400;

/** @lends ApIcon */
var ApIcon = _react2.default.createClass({
  displayName: 'ApIcon',


  // --------------------
  // Specs
  // --------------------

  propTypes: {},

  mixins: [_apemanReactMixinPure.ApPureMixin],

  statics: {
    /**
     * Check if has style.
     * @param className
     */
    hasStyleWithClass: function hasStyleWithClass(className) {
      var styleSheets = document.styleSheets || [];
      for (var i = 0; i < styleSheets.length; i++) {
        var styleSheet = styleSheets[i];
        var rules = styleSheet.rules || styleSheet.cssRules || [];
        for (var j = 0; j < rules.length; j++) {
          var rule = rules[j];
          var selectorText = rule.selectorText;
          var hit = selectorText && new RegExp('.' + className).test(selectorText);
          if (hit) {
            return true;
          }
        }
      }
      return false;
    },
    warnNotFound: function warnNotFound() {
      setTimeout(function () {
        if (notfoundCache.length > 0) {
          console.warn('[ApIcon] No style found for class ' + notfoundCache.map(function (notFound) {
            return '"' + notFound + '"';
          }).join(', ') + '.\nYou seeing this warning either because of:\n  1. Misspelling the name or missing some stylesheets.\n  2. Using stylesheets from another domain.');
          notfoundCache = [];
        }
      }, 100);
    },

    ASSERT_DELAY: ASSERT_DELAY
  },

  getInitialState: function getInitialState() {
    return {};
  },
  getDefaultProps: function getDefaultProps() {
    return {};
  },
  render: function render() {
    var s = this;
    var props = s.props;


    return _react2.default.createElement('i', { className: (0, _classnames2.default)('ap-icon', props.className),
      style: Object.assign({}, props.style) });
  },


  // --------------------
  // Lifecycle
  // --------------------

  componentDidMount: function componentDidMount() {
    var s = this;
    s.mounted = true;
    var props = s.props;

    s.assertClassName(props.className, { delay: 1200 });
  },
  componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
    var s = this;
    if (nextProps.hasOwnProperty('className')) {
      s.assertClassName(nextProps.className);
    }
  },
  componentWillUnmount: function componentWillUnmount() {
    var s = this;
    clearTimeout(s._assertTimer);
  },


  // ------------------
  // Helper
  // ------------------

  assertClassName: function assertClassName(className) {
    var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    if (!className) {
      return;
    }
    var s = this;
    clearTimeout(s._assertTimer);
    s._assertTimer = setTimeout(function () {
      if (!s.mounted) {
        return;
      }
      className.split(/\s/g).forEach(function (className) {
        if (!className) {
          return;
        }
        if (assertCache.hasOwnProperty(className)) {
          return;
        }
        if (/^ap/.test(className)) {
          return;
        }
        var valid = ApIcon.hasStyleWithClass(className);
        if (!valid) {
          notfoundCache.push(className);
        }
        assertCache[className] = valid;
      });
      ApIcon.warnNotFound();
    }, options.delay || ASSERT_DELAY);
  },


  // ------------------
  // Private
  // ------------------

  _assertTimer: -1
});

exports.default = ApIcon;
//# sourceMappingURL=data:application/json;base64,bnVsbA==